@@ -45,7 +45,6 @@ class MetaState(type):
     """
     def __init__(cls, classname, bases, newdict):
         super(MetaState, cls).__init__(classname, bases, newdict)
-        #slots = ['(is-a %s)' % bases[0].__name__]
         slots = ['(slot %s (type %s) (visibility public) (pattern-match reactive))' % (mod,
             issubclass(modclass, Number) and '?VARIABLE' or 'INSTANCE')
                   for mod,modclass in cls.mods.items()]
@@ -53,7 +52,6 @@ class MetaState(type):
         clp = '(defclass %s (is-a %s) %s)' % (classname,
                                               bases[0].__name__,
                                               slots)
-        clp_r = '(defrule (prop(s, p)) => s is-a S)' # XXX follow this? too many rules?
         logger.info(clp)
         clips.Build(clp)
         cls._v_clips_class = clips.FindClass(classname)
@@ -113,17 +111,8 @@ class State(Verb):
         for a slot constraint for a prop in a rule
         """
         newvar = _newvar()
-        if self.value in vrs:
-            if vrs[self.value]:
-                return '?%(val)s&:(eq ?%(val)s %(var)s)' % {'val': newvar,
-                                           'var': clips_instance(*(vrs[self.value]))}
-            else:
-                return '?%s' % self.value
-        elif self.value:
-            vrs[self.value] = ()
-            return class_constraint % {'val': self.value,
-                                         'cls': self.__class__.__name__}
-        newvar = _newvar()
+        if varpat.match(self.value):
+            return self.get_var_slot_constraint(vrs, newvar)
         constraint = [class_constraint % {'val': newvar,
                                          'cls': self.__class__.__name__}]
         for mod,cls in self.mods.items():
@@ -159,10 +148,7 @@ class State(Verb):
         put pred in clips as a make-instance action.
         """
         if self.value and varpat.match(self.value):
-            if self.value in vrs and vrs[self.value]:
-                return clips_instance(*(vrs[self.value]))
-            else:
-                return '?%s' % self.value
+            return self.put_var(vrs)
         slots = []
         for mod in self.mods:
             mod_o = getattr(self, mod, _m)
@@ -180,28 +166,25 @@ class State(Verb):
         newvar = _newvar()
         if self.value:
             if self.value in vrs:
-                templs.append('(?%s %s)' % (newvar,
-                                        self.__class__.__name__))
                 if vrs[self.value]:
                     queries.append('(eq ?%s %s)' % (newvar,
                                      clips_instance(*(vrs[self.value]))))
                 else:
-                    queries.append('(eq ?%s %s)' % (newvar,
-                                     self.value))
-                return '?%s' % newvar
-            return '?' + self.value
-        templs.append('(?%s %s)' % (newvar, self.__class__.__name__))
+                    newvar = self.value
+            else:
+                vrs[self.value] = ()
+                newvar = self.value
+        templs.append((newvar, self.__class__.__name__))
         for mod,mcls in self.mods.items():
             mod_o = getattr(self, mod, _m)
             if mod_o is not _m and not (varpat.match(mod_o.value) and mod_o.value not in vrs):
                 queries.append('(eq ?%s:%s %s)' % (newvar, mod,
                                                mod_o.get_isc(templs, queries, vrs)))
-        return '?' + newvar
+        return '?%s' % newvar
 
 
 register('State', State)
 
-#_init_daemon = '(defmessage-handler State init after () (python-call pred_tonl ?self))'
 _set_tal = '(set-sequence-operator-recognition TRUE)'
 
 _set_slots = """(defmessage-handler State set-slots primary ($?slots)
